@@ -41,6 +41,11 @@ where
         false
     }
 
+    #[inline]
+    fn skip_archetype(archetype: &Archetype, _: u64) -> bool {
+        !archetype.contains_id(TypeId::of::<T>())
+    }
+
     #[inline]
     unsafe fn fetch(archetype: &Archetype, _tracks: u64, _epoch: u64) -> Option<FetchRead<T>> {
         let idx = archetype.id_index(TypeId::of::<T>())?;
